##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/auth/operation/Logout)Logout
**Access policy** : public
##### Authorizations:
_ApiKeyAuth_ _jwt_
### Responses
**204**
Success
**500**
Server error
post/auth/logout
https://api-docs.portainer.io/api/auth/logout
